import { readFile } from 'node:fs'

import type { tags } from 'swf-types'

const defineTypeCompression = (data: Buffer): string => {
  // Define type compression from reading the three first bytes of the file
  // defineTypeCompression(data)

  return Array.from({ length: 3 })
    .map((_, index) => {
      return String.fromCharCode(data[index])
    })
    .join('')
}

readFile(process.cwd() + '/swfs/bunny.swf', async (error, data) => {
  const typeCompression = defineTypeCompression(data)

  if (error != null) throw new Error(String(error))
  if (typeCompression !== 'CWS') throw new Error(`New Type Compression detected: ${typeCompression}`)

  const SWF = (await import('swf-parser')).parseSwf(data)

  const images = SWF.tags.filter((tag) => {
    const mediaType = (tag as tags.DefineBitmap).mediaType
    return String(mediaType).startsWith('image')
  }) as tags.DefineBitmap[]

  const className = (
    SWF.tags.filter((tag) => {
      return (tag as tags.PlaceObject).name
    })[0] as tags.PlaceObject
  ).name

  const current = images.map((img) => {
    return {
      path: className,
      contents: img.data
    }
  })

  console.log(current)

  // const packerAtlas = await packAsync(current)
})
